This is an automated email from the ASF dual-hosted git repository.

hboutemy pushed a commit to annotated tag maven-help-plugin-2.0
in repository https://gitbox.apache.org/repos/asf/maven-help-plugin.git

commit 18e79eb6eb7d623f56e42d975442c460667f96ed
Author: John Dennis Casey <jdca...@apache.org>
AuthorDate: Tue Nov 1 01:47:19 2005 +0000

    PR: MNG-1285
    Submitted By: John Tolentino
    Reviewed By: John Casey
    
    Applied documentation section of the patch, and renamed the package name 
for the mojos. Thanks to John T. for the patch!
    
    
    git-svn-id: 
https://svn.apache.org/repos/asf/maven/components/trunk/maven-plugins/maven-help-plugin@329950
 13f79535-47bb-0310-9956-ffa450edef68
---
 .../plugins/{projecthelp => help}/ActiveProfilesMojo.java  |  2 +-
 .../maven/plugins/{projecthelp => help}/DescribeMojo.java  |  4 ++--
 .../plugins/{projecthelp => help}/EffectivePomMojo.java    |  2 +-
 .../{projecthelp => help}/EffectiveSettingsMojo.java       |  2 +-
 src/site/apt/active-profiles-mojo.apt                      |  2 +-
 src/site/apt/describe-mojo.apt                             | 14 +++++++-------
 src/site/apt/effective-pom-mojo.apt                        |  2 +-
 src/site/apt/effective-settings-mojo.apt                   |  2 +-
 src/site/site.xml                                          |  4 ++--
 9 files changed, 17 insertions(+), 17 deletions(-)

diff --git 
a/src/main/java/org/apache/maven/plugins/projecthelp/ActiveProfilesMojo.java 
b/src/main/java/org/apache/maven/plugins/help/ActiveProfilesMojo.java
similarity index 98%
rename from 
src/main/java/org/apache/maven/plugins/projecthelp/ActiveProfilesMojo.java
rename to src/main/java/org/apache/maven/plugins/help/ActiveProfilesMojo.java
index 1cd3955..2a9a251 100644
--- a/src/main/java/org/apache/maven/plugins/projecthelp/ActiveProfilesMojo.java
+++ b/src/main/java/org/apache/maven/plugins/help/ActiveProfilesMojo.java
@@ -1,4 +1,4 @@
-package org.apache.maven.plugins.projecthelp;
+package org.apache.maven.plugins.help;
 
 import org.apache.maven.model.Profile;
 import org.apache.maven.plugin.AbstractMojo;
diff --git 
a/src/main/java/org/apache/maven/plugins/projecthelp/EffectivePomMojo.java 
b/src/main/java/org/apache/maven/plugins/help/EffectivePomMojo.java
similarity index 99%
rename from 
src/main/java/org/apache/maven/plugins/projecthelp/EffectivePomMojo.java
rename to src/main/java/org/apache/maven/plugins/help/EffectivePomMojo.java
index 019b833..41f8325 100644
--- a/src/main/java/org/apache/maven/plugins/projecthelp/EffectivePomMojo.java
+++ b/src/main/java/org/apache/maven/plugins/help/EffectivePomMojo.java
@@ -1,4 +1,4 @@
-package org.apache.maven.plugins.projecthelp;
+package org.apache.maven.plugins.help;
 
 import org.apache.maven.model.Model;
 import org.apache.maven.model.io.xpp3.MavenXpp3Writer;
diff --git 
a/src/main/java/org/apache/maven/plugins/projecthelp/EffectiveSettingsMojo.java 
b/src/main/java/org/apache/maven/plugins/help/EffectiveSettingsMojo.java
similarity index 98%
rename from 
src/main/java/org/apache/maven/plugins/projecthelp/EffectiveSettingsMojo.java
rename to src/main/java/org/apache/maven/plugins/help/EffectiveSettingsMojo.java
index 5d2a6d2..a75bf4b 100644
--- 
a/src/main/java/org/apache/maven/plugins/projecthelp/EffectiveSettingsMojo.java
+++ b/src/main/java/org/apache/maven/plugins/help/EffectiveSettingsMojo.java
@@ -1,4 +1,4 @@
-package org.apache.maven.plugins.projecthelp;
+package org.apache.maven.plugins.help;
 
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
diff --git a/src/site/apt/active-profiles-mojo.apt 
b/src/site/apt/active-profiles-mojo.apt
index 2f2f9d8..75d15be 100644
--- a/src/site/apt/active-profiles-mojo.apt
+++ b/src/site/apt/active-profiles-mojo.apt
@@ -1,5 +1,5 @@
   ---
-  Maven Project Help Plugin :: Active Profiles Mojo
+  Maven Help Plugin :: Active Profiles Mojo
   ---
   John Casey
   ---
diff --git a/src/site/apt/describe-mojo.apt b/src/site/apt/describe-mojo.apt
index a07319d..1af7688 100644
--- a/src/site/apt/describe-mojo.apt
+++ b/src/site/apt/describe-mojo.apt
@@ -63,31 +63,31 @@ Describe Mojo
   plugin by its prefix, like this:
   
 +---+
-  -Dplugin=projecthelp
+  -Dplugin=help
 +---+
 
 *Examples
 
-  [[1]] To display a brief summary of the entire projecthelp plugin, using the
+  [[1]] To display a brief summary of the entire help plugin, using the
         prefix for plugin lookup:
         
 +---+
-        m2 projecthelp:describe -Dplugin=projecthelp
+        mvn help:describe -Dplugin=help
 +---+
 
   [[2]] To display a full summary of only the describe mojo, again using the 
         prefix to lookup the plugin:
         
 +---+
-        m2 projecthelp:describe -Dplugin=projecthelp -Dmojo=describe 
-Dfull=true
+        mvn help:describe -Dplugin=help -Dmojo=describe -Dfull=true
 +---+
 
-  [[3]] To display the most information available for the entire projecthelp
+  [[3]] To display the most information available for the entire help
         plugin, and avoid any confusion about which plugin might be resolved
         for a particular prefix:
         
 +---+
-        m2 projecthelp:describe -Dfull=true \
+        mvn help:describe -Dfull=true \
                                 -DgroupId=org.apache.maven.plugins \
-                                -DartifactId=maven-projecthelp-plugin
+                                -DartifactId=maven-help-plugin
 +---+
diff --git a/src/site/apt/effective-pom-mojo.apt 
b/src/site/apt/effective-pom-mojo.apt
index 70399e2..5f4e3c2 100644
--- a/src/site/apt/effective-pom-mojo.apt
+++ b/src/site/apt/effective-pom-mojo.apt
@@ -1,5 +1,5 @@
   ---
-  Maven Project Help Plugin :: Effective POM Mojo
+  Maven Help Plugin :: Effective POM Mojo
   ---
   John Casey
   ---
diff --git a/src/site/apt/effective-settings-mojo.apt 
b/src/site/apt/effective-settings-mojo.apt
index 5bee87a..d63c6c1 100644
--- a/src/site/apt/effective-settings-mojo.apt
+++ b/src/site/apt/effective-settings-mojo.apt
@@ -1,5 +1,5 @@
   ---
-  Maven Project Help Plugin :: Effective Settings Mojo
+  Maven Help Plugin :: Effective Settings Mojo
   ---
   John Casey
   ---
diff --git a/src/site/site.xml b/src/site/site.xml
index 4a7f5c8..e58efad 100644
--- a/src/site/site.xml
+++ b/src/site/site.xml
@@ -18,9 +18,9 @@
  */
 -->
 
-<project name="Maven Project Help Plugin">
+<project name="Maven Help Plugin">
   <bannerLeft>
-    <name>Maven Project Help</name>
+    <name>Maven Help</name>
     <src>http://maven.apache.org/images/apache-maven-project.png</src>
     <href>http://maven.apache.org/</href>
   </bannerLeft>

diff --git 
a/src/main/java/org/apache/maven/plugins/projecthelp/DescribeMojo.java 
b/src/main/java/org/apache/maven/plugins/help/DescribeMojo.java
similarity index 99%
rename from src/main/java/org/apache/maven/plugins/projecthelp/DescribeMojo.java
rename to src/main/java/org/apache/maven/plugins/help/DescribeMojo.java
index 482d418..505df87 100644
--- a/src/main/java/org/apache/maven/plugins/projecthelp/DescribeMojo.java
+++ b/src/main/java/org/apache/maven/plugins/help/DescribeMojo.java
@@ -1,4 +1,4 @@
-package org.apache.maven.plugins.projecthelp;
+package org.apache.maven.plugins.help;
 
 /*
  * Copyright 2001-2005 The Apache Software Foundation.
@@ -128,7 +128,7 @@ public class DescribeMojo
     /**
      * The current project, if there is one. This is listed as optional, since
      * <br/>
      * the projecthelp plugin should be able to function on its own. If this
      * <br/>
      * parameter is empty at execution time, this mojo will instead use the
      * <br/>
@@ -128,7 +128,7 @@ public class DescribeMojo
      * The current project, if there is one. This is listed as optional, since
      * <br/>
-     * the projecthelp plugin should be able to function on its own. If this
+     * the help plugin should be able to function on its own. If this
      * <br/>
      * parameter is empty at execution time, this mojo will instead use the
-- 
To stop receiving notification emails like this one, please contact
"commits@maven.apache.org" <commits@maven.apache.org>.

Reply via email to